//
// C++ Interface: CGlobalEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CGLOBALEDITDLG_H
#define CGLOBALEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_globaldlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"


class CGlobalEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CGlobalEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CGlobalEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
 
private slots:
 
protected:
    Ui::GlobalEditDlg ui;    
    FolderListItem *point;
    
private:
    QWidget *myParent;
};
#endif
